@@ -349,6 +349,57 @@ class ConValue(IntEnum):
     PROPORTIONAL_LOCKED = 1,
     PROPORTIONAL_LOCKED_HIDDEN = 6,
     UNDEFINED = -2147483648,
+class CountryCode(IntEnum):
+    ALGERIA = 213,
+    AUSTRALIA = 61,
+    AUSTRIA = 43,
+    BELGIUM = 32,
+    BRAZIL = 55,
+    CANADA = 2,
+    CHINA = 86,
+    CZECH = 420,
+    DEFAULT = 0,
+    DENMARK = 45,
+    EGYPT = 20,
+    FINLAND = 358,
+    FRANCE = 33,
+    GERMANY = 49,
+    GREECE = 30,
+    HUNGARY = 36,
+    ICELAND = 354,
+    INDIA = 91,
+    IRAN = 981,
+    IRAQ = 964,
+    ISRAEL = 972,
+    ITALY = 39,
+    JAPAN = 81,
+    JORDAN = 962,
+    KUWAIT = 965,
+    LATIN_AMERIC = 3,
+    LEBANON = 961,
+    LIBYA = 218,
+    MEXICO = 52,
+    MOROCCO = 216,
+    NETHERLANDS = 31,
+    NEW_ZEALAND = 64,
+    NORWAY = 47,
+    POLAND = 48,
+    PORTUGAL = 351,
+    QATAR = 974,
+    RUSSIA = 7,
+    SAUDI = 966,
+    SOUTH_KOREA = 82,
+    SPAIN = 34,
+    SWEDEN = 46,
+    SWITZERLAND = 41,
+    SYRIA = 963,
+    TAIWAN = 886,
+    THAILAND = 66,
+    TURKEY = 90,
+    UNITED_ARAB_EMIRATES = 971,
+    UNITED_KINGDOM = 44,
+    USA = 1,
+    VIET_NAM = 84,
 class DataConnectionType(IntEnum):
     ODBC = 2,
     QLEDB = 1,
@@ -1525,7 +1576,6 @@ from com.aspose.diagram import PageLineJumpDirX
 from com.aspose.diagram import PageLineJumpDirY
 from com.aspose.diagram import PageSize
 from com.aspose.diagram import Para
-from com.aspose.diagram import PdfDigitalSignatureDetails
 from com.aspose.diagram import PdfEncryptionDetails
 from com.aspose.diagram import PdfSaveOptions
 from com.aspose.diagram import PlaceDepth
